==> foundation-ui-components-1.13.0.tgz: package/src/common/card/NsMediumCard.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

import { NsImage, NsTypography } from '../';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsMediumCardProps = {
    title: string;
    titleFontWeight?: 'bold' | 'normal' | 'light';
    subtitle: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    button?: NsCardButton;
    className?: string;
    fluid?: boolean;
};
const textVariantButton = {
    padding: '0 0 4px',
    gap: '7px',
    span: {
        margin: 0,
    },
    '>div': {
        margin: 0,
        borderBottom: '1px solid #252525',
    },
    '.MuiButton-endIcon': {
        svg: {
            g: {
                strokeWidth: 2,
            },
        },
    },
};
const buttonVariantStyle = (variant: string) => (variant === 'text' ? { a: textVariantButton } : {});
const CardContainer = styled(Box)<{ fluid: boolean; variant: string }>(({ fluid, variant }) => {
    const textVariantCssModification = buttonVariantStyle(variant);

    return {
        display: 'flex',
        flexDirection: 'column',
        position: 'relative',
        '.image': {
            width: fluid ? '100%' : '300px',
            height: '300px',
            objectFit: 'cover',
        },
        '.content': {
            display: 'flex',
            width: fluid ? '100%' : '300px',
            flexDirection: 'column',
        },
        '.subtitle': {
            fontSize: '16px',
            fontWeight: '400',
            marginTop: '10px',
        },
        '.title': {
            fontSize: '20px',
            marginTop: '10px',
        },
        '.cta': {
            marginTop: '10px',
            ...textVariantCssModification,
        },
    };
});

export default function NsMediumCard({
    title,
    titleFontWeight,
    subtitle,
    backgroundImageUrl,
    backgroundImageAlt,
    button,
    className,
    fluid,
}: NsMediumCardProps) {
    return (
        <CardContainer
            className={className}
            role="medium-card"
            component="div"
            data-testid="medium-card"
            fluid={fluid || false}
            variant={button?.buttonVariant ?? ''}
        >
            <NsImage alt={backgroundImageAlt} src={backgroundImageUrl} className="image" />
            <div className="content">
                <NsTypography variant="h5" color="primary" className="title" weight={titleFontWeight}>
                    {title}
                </NsTypography>
                <article className="subtitle">{subtitle}</article>
                {button ? <CardButton {...button} /> : null}
            </div>
        </CardContainer>
    );
}

==> foundation-ui-components-1.15.0.tgz: package/src/common/card/NsMediumCard.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

import { NsImage, NsTypography } from '../';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsMediumCardProps = {
    title: string;
    titleFontWeight?: 'bold' | 'normal' | 'light';
    subtitle: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    button?: NsCardButton;
    className?: string;
    fluid?: boolean;
    showArrowWithButtonText?: boolean;
};
const textVariantButton = {
    padding: '0 0 4px',
    gap: '7px',
    span: {
        margin: 0,
    },
    '>div': {
        margin: 0,
        borderBottom: '1px solid #252525',
    },
    '.MuiButton-endIcon': {
        svg: {
            g: {
                strokeWidth: 2,
            },
        },
    },
};
const buttonVariantStyle = (variant: string) => (variant === 'text' ? { a: textVariantButton } : {});
const CardContainer = styled(Box)<{ fluid: boolean; variant: string }>(({ fluid, variant }) => {
    const textVariantCssModification = buttonVariantStyle(variant);

    return {
        display: 'flex',
        flexDirection: 'column',
        position: 'relative',
        '.image': {
            width: fluid ? '100%' : '300px',
            height: '300px',
            objectFit: 'cover',
        },
        '.content': {
            display: 'flex',
            width: fluid ? '100%' : '300px',
            flexDirection: 'column',
        },
        '.subtitle': {
            fontSize: '16px',
            fontWeight: '400',
            marginTop: '10px',
        },
        '.title': {
            fontSize: '20px',
            marginTop: '10px',
        },
        '.cta': {
            marginTop: '10px',
            ...textVariantCssModification,
        },
    };
});

export default function NsMediumCard({
    title,
    titleFontWeight,
    subtitle,
    backgroundImageUrl,
    backgroundImageAlt,
    button,
    className,
    fluid,
    showArrowWithButtonText = false,
}: NsMediumCardProps) {
    return (
        <CardContainer
            className={className}
            role="medium-card"
            component="div"
            data-testid="medium-card"
            fluid={fluid || false}
            variant={button?.buttonVariant ?? ''}
        >
            <NsImage alt={backgroundImageAlt} src={backgroundImageUrl} className="image" />
            <div className="content">
                <NsTypography variant="h5" color="primary" className="title" weight={titleFontWeight}>
                    {title}
                </NsTypography>
                <article className="subtitle">{subtitle}</article>
                {button ? <CardButton {...button} showArrowWithText={showArrowWithButtonText} /> : null}
            </div>
        </CardContainer>
    );
}
